#ifndef ACCURACYGRAPH_H
#define ACCURACYGRAPH_H

#include <rx/columbus/ColumbusModel.h>

#include "AbstractChart.h"

class AccuracyGraphPrivate;

class AccuracyGraph : public AbstractChart
{
    Q_OBJECT

public:
    explicit     AccuracyGraph  (QWidget *parent = 0);
                ~AccuracyGraph  ();

    void         setModel(ColumbusModel *model);

protected:
    void         paintEvent     (QPaintEvent *event);

    AccuracyGraphPrivate *d;
};

#endif // ACCURACYGRAPH_H
